@@ -12,7 +12,7 @@
 #'   min annd max wavelengths (nm)
 #' @param pc.out logical, if TRUE use percents instead of fraction of one
 #' @param label.qty character string giving the type of summary quantity to use
-#'   for labels
+#'   for labels, one of "mean", "total", "contribution", and "relative".
 #' @param span a peak is defined as an element in a sequence which is greater
 #'   than all other elements within a window of width span centered at that
 #'   element.
@@ -162,6 +162,13 @@ e_rsp_plot <- function(spct,
   }
 
   plot <- ggplot(spct, aes_(~w.length, ~s.e.response))
+
+  # We want data plotted on top of the boundary lines
+  # Negative response is valid!
+  if ("boundaries" %in% annotations) {
+    plot <- plot + geom_hline(yintercept = 0, linetype = "dashed", colour = "black")
+  }
+
   plot <- plot + geom_line(na.rm = na.rm)
   plot <- plot + labs(x = "Wavelength (nm)", y = s.rsp.label)
 
@@ -203,6 +210,7 @@ e_rsp_plot <- function(spct,
     y.limits <- c(y.min, y.max)
     x.limits <- range(spct)
   }
+
   if (abs(y.min) < 5e-2 && (abs(y.max - 1) < 5.e-2)) {
     plot <- plot +
       scale_y_continuous(breaks = c(0, 0.25, 0.5, 0.75, 1), limits = y.limits)
@@ -226,7 +234,7 @@ e_rsp_plot <- function(spct,
 #'   min annd max wavelengths (nm)
 #' @param pc.out logical, if TRUE use percents instead of fraction of one
 #' @param label.qty character string giving the type of summary quantity to use
-#'   for labels
+#'   for labels, one of "mean", "total", "contribution", and "relative".
 #' @param span a peak is defined as an element in a sequence which is greater
 #'   than all other elements within a window of width span centered at that
 #'   element.
@@ -376,6 +384,13 @@ q_rsp_plot <- function(spct,
   }
 
   plot <- ggplot(spct, aes_(~w.length, ~s.q.response))
+
+  # We want data plotted on top of the boundary lines
+  # Negative response is valid!
+  if ("boundaries" %in% annotations) {
+    plot <- plot + geom_hline(yintercept = 0, linetype = "dashed", colour = "black")
+  }
+
   plot <- plot + geom_line(na.rm = na.rm)
   plot <- plot + labs(x = "Wavelength (nm)", y = s.rsp.label)
 
@@ -417,6 +432,7 @@ q_rsp_plot <- function(spct,
     y.limits <- c(y.min, y.max)
     x.limits <- range(spct)
   }
+
   if (abs(y.min) < 5e-2 && (abs(y.max - 1) < 5.e-2)) {
     plot <- plot +
       scale_y_continuous(breaks = c(0, 0.25, 0.5, 0.75, 1), limits = y.limits)
@@ -443,7 +459,7 @@ q_rsp_plot <- function(spct,
 #'   for plotting: "photon" or its synomin "quantum", or "energy"
 #' @param pc.out logical, if TRUE use percents instead of fraction of one
 #' @param label.qty character string giving the type of summary quantity to use
-#'   for labels
+#'   for labels, one of "mean", "total", "contribution", and "relative".
 #' @param span a peak is defined as an element in a sequence which is greater
 #'   than all other elements within a window of width span centered at that
 #'   element.
