@@ -95,12 +95,16 @@
 #' @examples
 #' library(photobiology)
 #' library(ggplot2)
-#' library(ggrepel)
 #' # ggplot() methods for spectral objects set a default mapping for x and y.
 #' ggplot(sun.spct) + geom_line() +
 #'   stat_label_peaks(hjust = "left", span = 31, angle = 90, color = "red")
 #' ggplot(sun.spct) + geom_line() +
 #'   stat_label_valleys(hjust = "right", span = 21, angle = 90, color = "blue")
+#'
+#' # using 'ggrepel' to avoid overlaps
+#' # too slow for CRAN checks
+#' \dontrun{
+#' library(ggrepel)
 #' ggplot(sun.spct) + geom_line() +
 #'   stat_peaks(span = 41, shape = 21, size = 3) +
 #'   stat_label_peaks(span = 41, geom = "label_repel", segment.colour = "red",
@@ -108,6 +112,8 @@
 #'   scale_fill_identity() +
 #'   scale_color_identity() +
 #'   expand_limits(y = c(NA, 1))
+#' }
+#'
 #' @export
 #' @family stats functions
 #'
@@ -183,7 +189,7 @@ StatLabelPeaks <-
                      )
                      data[["color"]] <- with(data,
                                              ifelse(is_peak,
-                                                    photobiology::color(x, type = "CMF"),
+                                                    photobiology::color_of(x, type = "CMF"),
                                                     "white")
                      )
                      data[["BW.color"]] <- with(data,
@@ -262,7 +268,7 @@ StatLabelValleys <-
                      )
                      data[["color"]] <- with(data,
                                              ifelse(is_valley,
-                                                    photobiology::color(x, type = "CMF"),
+                                                    photobiology::color_of(x, type = "CMF"),
                                                     "white")
                      )
                      data[["BW.color"]] <- with(data,
