@@ -168,7 +168,8 @@ StatWbRelative <-
                        range <- range(wb)
                        mydata <- trim_tails(data$x, data$y, use.hinges = TRUE,
                                             low.limit = range[1],
-                                            high.limit = range[2])
+                                            high.limit = range[2],
+                                            verbose = FALSE)
                        if (is_effective(wb)) {
                          warning("BSWFs not supported by summary: using wavelength range for ",
                                  labels(wb)$label, "'.")
@@ -184,9 +185,9 @@ StatWbRelative <-
                                                     ymax = max(data$y),
                                                     yint = yint.tmp,
                                                     ymean = ymean.tmp,
-                                                    wb.color = color(wb),
+                                                    wb.color = color_of(wb),
                                                     wb.name = labels(wb)$label,
-                                                    BW.color = black_or_white(color(wb)))
+                                                    BW.color = black_or_white(color_of(wb)))
                                          )
                      }
                      if (is.null(ypos.fixed)) {
